@@ -96,7 +96,7 @@ class KTEXTEDITOR_EXPORT KTextEditor::DocumentPrivate : public KTextEditor::Docu
 
 public:
     explicit DocumentPrivate(bool bSingleViewMode = false, bool bReadOnly = false,
-                          QWidget *parentWidget = 0, QObject * = 0);
+                          QWidget *parentWidget = nullptr, QObject * = nullptr);
     ~DocumentPrivate();
 
     using ReadWritePart::closeUrl;
@@ -136,7 +136,7 @@ private:
     // KTextEditor::Document stuff
     //
 public:
-    KTextEditor::View *createView(QWidget *parent, KTextEditor::MainWindow *mainWindow = Q_NULLPTR) Q_DECL_OVERRIDE;
+    KTextEditor::View *createView(QWidget *parent, KTextEditor::MainWindow *mainWindow = nullptr) Q_DECL_OVERRIDE;
 
     QList<KTextEditor::View *> views() const Q_DECL_OVERRIDE
     {
@@ -295,7 +295,7 @@ public:
      * @param newLineAdded return value is true, if new line was added (may be 0)
      * @return true on success
      */
-    bool editWrapLine(int line, int col, bool newLine = true, bool *newLineAdded = 0);
+    bool editWrapLine(int line, int col, bool newLine = true, bool *newLineAdded = nullptr);
     /**
      * Unwrap @p line. If @p removeLine is true, we force to join the lines. If
      * @p removeLine is true, @p length is ignored (eg not needed).
@@ -456,18 +456,18 @@ public:
      */
     bool setHighlightingMode(const QString &name) Q_DECL_OVERRIDE;
     /**
-     * Returns the name of the section for a highlight given its index in the highlight
+     * Returns the name of the section for a highlight given its @p index in the highlight
      * list (as returned by highlightModes()).
      * You can use this function to build a tree of the highlight names, organized in sections.
-     * \param name the name of the highlight for which to find the section name.
+     * \param index in the highlight list for which to find the section name.
      */
     QString highlightingModeSection(int index) const Q_DECL_OVERRIDE;
 
     /**
-     * Returns the name of the section for a mode given its index in the highlight
+     * Returns the name of the section for a mode given its @p index in the highlight
      * list (as returned by modes()).
      * You can use this function to build a tree of the mode names, organized in sections.
-     * \param name the name of the highlight for which to find the section name.
+     * \param index index in the highlight list for which to find the section name.
      */
     QString modeSection(int index) const Q_DECL_OVERRIDE;
 
@@ -633,7 +633,7 @@ public:
      * @param emptyBehavior behavior on becoming empty
      * @return new moving range for the document
      */
-    virtual KTextEditor::MovingRange *newMovingRange(const KTextEditor::Range &range, KTextEditor::MovingRange::InsertBehaviors insertBehaviors = KTextEditor::MovingRange::DoNotExpand
+    KTextEditor::MovingRange *newMovingRange(const KTextEditor::Range &range, KTextEditor::MovingRange::InsertBehaviors insertBehaviors = KTextEditor::MovingRange::DoNotExpand
             , KTextEditor::MovingRange::EmptyBehavior emptyBehavior = KTextEditor::MovingRange::AllowEmpty) Q_DECL_OVERRIDE;
 
     /**
@@ -933,7 +933,7 @@ public Q_SLOTS:
      * Ask the user what to do, if the file has been modified on disk.
      * Reimplemented from KTextEditor::Document.
      */
-    virtual void slotModifiedOnDisk(KTextEditor::View *v = 0);
+    virtual void slotModifiedOnDisk(KTextEditor::View *v = nullptr);
 
     /**
      * Reloads the current document from disk if possible
