@@ -63,6 +63,9 @@ KateRenderer::KateRenderer(KTextEditor::DocumentPrivate *doc, Kate::TextFolding
 
     // initialize with a sane font height
     updateFontHeight();
+
+    // make the proper calculation for markerSize
+    updateMarkerSize();
 }
 
 KateRenderer::~KateRenderer()
@@ -267,7 +270,8 @@ void KateRenderer::paintTrailingSpace(QPainter &paint, qreal x, qreal y)
 {
     QPen penBackup(paint.pen());
     QPen pen(config()->tabMarkerColor());
-    pen.setWidthF(spaceWidth() / 3.5);
+
+    pen.setWidthF(m_markerSize);
     pen.setCapStyle(Qt::RoundCap);
     paint.setPen(pen);
     paint.setRenderHint(QPainter::Antialiasing, true);
@@ -724,7 +728,11 @@ void KateRenderer::paintTextLine(QPainter &paint, KateLineLayoutPtr range, int x
                 if (spaceIndex >= trailingPos) {
                     while (spaceIndex >= line.startCol() && text.at(spaceIndex).isSpace()) {
                         if (text.at(spaceIndex) != QLatin1Char('\t') || !showTabs()) {
-                            paintTrailingSpace(paint, line.lineLayout().cursorToX(spaceIndex) - xStart + spaceWidth() / 2.0, y);
+                            if (range->layout()->textOption().alignment() == Qt::AlignRight) { // Draw on left for RTL lines
+                                paintTrailingSpace(paint, line.lineLayout().cursorToX(spaceIndex) - xStart - spaceWidth() / 2.0, y);
+                            } else {
+                                paintTrailingSpace(paint, line.lineLayout().cursorToX(spaceIndex) - xStart + spaceWidth() / 2.0, y);
+                            }
                         }
                         --spaceIndex;
                     }
@@ -938,10 +946,17 @@ void KateRenderer::updateConfig()
 
 void KateRenderer::updateFontHeight()
 {
-    // use height of font + round down, ensure we have at least one pixel
-    // we round down to avoid artifacts: line height too large vs. qt background rendering of text attributes
-    const qreal height = config()->fontMetrics().height();
-    m_fontHeight = qMax(1, qFloor(height));
+    // ensure minimal height of one pixel to not fall in the div by 0 trap somewhere
+    // use font line spacing, this includes the leading
+    m_fontHeight = qMax(1, qCeil(config()->fontMetrics().lineSpacing()));
+}
+
+void KateRenderer::updateMarkerSize()
+{
+    // marker size will be calculated over the value defined
+    // on dialog
+
+    m_markerSize = spaceWidth() / (3.5 - (m_doc->config()->markerSize() * 0.5));
 }
 
 qreal KateRenderer::spaceWidth() const
@@ -1015,6 +1030,9 @@ void KateRenderer::layoutLine(KateLineLayoutPtr lineLayout, int maxwidth, bool c
             line.setLineWidth(maxwidth);
         }
 
+        // we include the leading, this must match the ::updateFontHeight code!
+        line.setLeadingIncluded(true);
+
         line.setPosition(QPoint(line.lineNumber() ? shiftX : 0, height));
 
         if (needShiftX && line.width() > 0)
